@@ -141,8 +141,7 @@ class BatchCrud(CrudView):
 class ExecuteBatch(View):
 
     def execute_batch(self, batch, progress):
-        from rattail.db import get_session_class
-        Session = get_session_class(edbob.config)
+        from rattail.db import Session
         session = Session()
         batch = session.merge(batch)
 
