@@ -26,8 +26,10 @@
 Product Views
 """
 
+import os
+
 from sqlalchemy import and_
-from sqlalchemy.orm import joinedload
+from sqlalchemy.orm import joinedload, aliased
 
 from webhelpers.html.tags import link_to
 
@@ -42,11 +44,13 @@ from rattail import sil
 from rattail import batches
 from rattail.threads import Thread
 from rattail.exceptions import LabelPrintingError
+from rattail.db import model
 from rattail.db.model import (
     Product, ProductPrice, ProductCost, ProductCode,
     Brand, Vendor, Department, Subdepartment, LabelProfile)
 from rattail.gpc import GPC
 from rattail.db.api import get_product_by_upc
+from rattail.pod import get_image_url, get_image_path
 
 from ..db import Session
 from ..forms import GPCFieldRenderer, BrandFieldRenderer, PriceFieldRenderer
@@ -60,22 +64,38 @@ class ProductsGrid(SearchableAlchemyGridView):
     config_prefix = 'products'
     sort = 'description'
 
+    # These aliases enable the grid queries to filter products which may be
+    # purchased from *any* vendor, and yet sort by only the "preferred" vendor
+    # (since that's what shows up in the grid column).
+    ProductCostAny = aliased(ProductCost)
+    VendorAny = aliased(Vendor)
+
     def join_map(self):
 
-        # def join_vendor(q):
-        #     q = q.outerjoin(
-        #         ProductCost,
-        #         ProductCost.product_uuid == Product.uuid,
-        #         and_(
-        #             ProductCost.product_uuid == Product.uuid,
-        #             ProductCost.preference == 1,
-        #             ))
-        #     q = q.outerjoin(Vendor)
-        #     return q
+        def join_vendor(q):
+            q = q.outerjoin(
+                ProductCost,
+                and_(
+                    ProductCost.product_uuid == Product.uuid,
+                    ProductCost.preference == 1,
+                    ))
+            q = q.outerjoin(Vendor)
+            return q
+
+        def join_vendor_any(q):
+            q = q.outerjoin(
+                self.ProductCostAny,
+                self.ProductCostAny.product_uuid == Product.uuid)
+            q = q.outerjoin(
+                self.VendorAny,
+                self.VendorAny.uuid == self.ProductCostAny.vendor_uuid)
+            return q
 
         return {
             'brand':
                 lambda q: q.outerjoin(Brand),
+            'family':
+                lambda q: q.outerjoin(model.Family),
             'department':
                 lambda q: q.outerjoin(Department,
                                       Department.uuid == Product.department_uuid),
@@ -88,10 +108,10 @@ class ProductsGrid(SearchableAlchemyGridView):
             'current_price':
                 lambda q: q.outerjoin(ProductPrice,
                                       ProductPrice.uuid == Product.current_price_uuid),
-            # 'vendor':
-            #     join_vendor,
+            'vendor':
+                join_vendor,
             'vendor_any':
-                lambda q: q.outerjoin(ProductCost, ProductCost.product_uuid == Product.uuid).outerjoin(Vendor),
+                join_vendor_any,
             'code':
                 lambda q: q.outerjoin(ProductCode),
             }
@@ -124,10 +144,11 @@ class ProductsGrid(SearchableAlchemyGridView):
             ilike=['description', 'size'],
             upc=filter_upc(),
             brand=self.filter_ilike(Brand.name),
+            family=self.filter_ilike(model.Family.name),
             department=self.filter_ilike(Department.name),
             subdepartment=self.filter_ilike(Subdepartment.name),
-            # vendor=self.filter_ilike(Vendor.name),
-            vendor_any=self.filter_ilike(Vendor.name),
+            vendor=self.filter_ilike(Vendor.name),
+            vendor_any=self.filter_ilike(self.VendorAny.name),
             code=self.filter_ilike(ProductCode.code))
 
     def filter_config(self):
@@ -141,6 +162,7 @@ class ProductsGrid(SearchableAlchemyGridView):
             filter_type_description='lk',
             include_filter_department=True,
             filter_type_department='lk',
+            filter_label_vendor="Vendor (preferred)",
             include_filter_vendor_any=True,
             filter_label_vendor_any="Vendor (any)",
             filter_type_vendor_any='lk')
@@ -245,6 +267,18 @@ class ProductCrud(CrudView):
             del fs.current_price
         return fs
 
+    def template_kwargs(self, form):
+        kwargs = {'image': False}
+        product = form.fieldset.model
+        if product.upc:
+            kwargs['image_url'] = get_image_url(
+                self.request.rattail_config, product.upc)
+            kwargs['image_path'] = get_image_path(
+                self.request.rattail_config, product.upc)
+            if os.path.exists(kwargs['image_path']):
+                kwargs['image'] = True
+        return kwargs
+
 
 def products_search(request):
     """
