@@ -26,16 +26,19 @@
 Report Views
 """
 
+import re
+
 from .core import View
 from mako.template import Template
 from pyramid.response import Response
 
 from ..db import Session
-from rattail.db.model import Vendor, Department, Product, ProductCost
 
-import re
-import rattail
 from edbob.time import local_time
+
+import rattail
+from rattail import enum
+from rattail.db import model
 from rattail.files import resource_path
 
 
@@ -64,13 +67,13 @@ class OrderingWorksheet(View):
 
     def __call__(self):
         if self.request.params.get('vendor'):
-            vendor = Session.query(Vendor).get(self.request.params['vendor'])
+            vendor = Session.query(model.Vendor).get(self.request.params['vendor'])
             if vendor:
                 departments = []
                 uuids = self.request.params.get('departments')
                 if uuids:
                     for uuid in uuids.split(','):
-                        dept = Session.query(Department).get(uuid)
+                        dept = Session.query(model.Department).get(uuid)
                         if dept:
                             departments.append(dept)
                 preferred_only = self.request.params.get('preferred_only') == '1'
@@ -87,12 +90,12 @@ class OrderingWorksheet(View):
         Rendering engine for the ordering worksheet report.
         """
 
-        q = Session.query(ProductCost)
-        q = q.join(Product)
-        q = q.filter(ProductCost.vendor == vendor)
-        q = q.filter(Product.department_uuid.in_([x.uuid for x in departments]))
+        q = Session.query(model.ProductCost)
+        q = q.join(model.Product)
+        q = q.filter(model.ProductCost.vendor == vendor)
+        q = q.filter(model.Product.department_uuid.in_([x.uuid for x in departments]))
         if preferred_only:
-            q = q.filter(ProductCost.preference == 1)
+            q = q.filter(model.ProductCost.preference == 1)
 
         costs = {}
         for cost in q:
@@ -138,7 +141,7 @@ class InventoryWorksheet(View):
         This is the "Inventory Worksheet" report.
         """
 
-        departments = Session.query(Department)
+        departments = Session.query(model.Department)
 
         if self.request.params.get('department'):
             department = departments.get(self.request.params['department'])
@@ -150,7 +153,7 @@ class InventoryWorksheet(View):
                 response.text = body
                 return response
 
-        departments = departments.order_by(rattail.Department.name)
+        departments = departments.order_by(model.Department.name)
         departments = departments.all()
         return{'departments': departments}
 
@@ -160,12 +163,12 @@ class InventoryWorksheet(View):
         """
 
         def get_products(subdepartment):
-            q = Session.query(rattail.Product)
-            q = q.outerjoin(rattail.Brand)
-            q = q.filter(rattail.Product.subdepartment == subdepartment)
+            q = Session.query(model.Product)
+            q = q.outerjoin(model.Brand)
+            q = q.filter(model.Product.subdepartment == subdepartment)
             if self.request.params.get('weighted-only'):
-                q = q.filter(rattail.Product.unit_of_measure == rattail.UNIT_OF_MEASURE_POUND)
-            q = q.order_by(rattail.Brand.name, rattail.Product.description)
+                q = q.filter(model.Product.unit_of_measure == enum.UNIT_OF_MEASURE_POUND)
+            q = q.order_by(model.Brand.name, model.Product.description)
             return q.all()
 
         now = local_time()
